//
//  ViewController.swift
//  Uhr
//
//  Created by Holger Hinzberg on 31.08.17.
//  Copyright © 2017 Holger Hinzberg. All rights reserved.
//

import UIKit

class ViewController: UIViewController
{
    // Der Timer wird in der Klasse definiert
    var timer:Timer?
 
    // Eine Verbindung zu einem Label auf der grafische Oberfläche
    @IBOutlet var uhrzeitLabel:UILabel?
    
    // Verbindungen zu den Label
    @IBOutlet var stundenLabel:UILabel?
    @IBOutlet var minutenLabel:UILabel?
    @IBOutlet var sekundenLabel:UILabel?
    // Verbindungen zu den Fortschrittsbalken
    @IBOutlet var stundenFortschritt: UIProgressView?
    @IBOutlet var minutenFortschritt: UIProgressView?
    @IBOutlet var sekundenFortschritt: UIProgressView?
    
    override func viewDidLoad()
    {
        super.viewDidLoad()
        
        self.stundenLabel?.text = ""
        self.minutenLabel?.text = ""
        self.sekundenLabel?.text = ""
        self.uhrzeitLabel?.text = ""
        
        self.stundenFortschritt?.progress = 0
        self.minutenFortschritt?.progress = 0
        self.sekundenFortschritt?.progress = 0
        
        /*
        // Einen Timer anlegen und konfigurieren
        self.timer = Timer.scheduledTimer(timeInterval: 1.0,
                           target: self, selector: #selector(timerTick),
                           userInfo: nil, repeats: true)
        */
        
        // Einen Timer anlegen und konfigurieren mit einer Closure
        self.timer = Timer.scheduledTimer(withTimeInterval: 1.0, repeats: true)
        {
            timer in

            // Eine formatierte Uhrzeit als Zeichenkette
            // erzeugen.
            let datum = Date()
            let dateFormatter = DateFormatter()
            dateFormatter.dateFormat = "HH:mm:ss"
            
            let uhrzeit = dateFormatter.string(from: datum)
            // Die Uhrzeit an das Label übergeben
            self.uhrzeitLabel?.text = uhrzeit
            
            // Die einzelnen Teile der Zeit aus dem
            // Date-Objekt auslesen
            let kalendar = Calendar.current
            let stunden = kalendar.component(.hour , from: datum)
            let minuten = kalendar.component(.minute, from: datum)
            let sekunden = kalendar.component(.second, from: datum)
            
            // Die einzelnen Teile der Zeit in die
            // Bezeichnungsfelder schreiben
            self.stundenLabel?.text = "\(stunden)"
            self.minutenLabel?.text = "\(minuten)"
            self.sekundenLabel?.text = "\(sekunden)"
            
            // Die Werte für die Fortschrittsbalken anpassen
            let progressStunden = Float(stunden) / 24.0
            let progressMinuten = Float(minuten) / 60.0
            let progressSekunden = Float(sekunden) / 60.0
            
            // Zuweisung der Werte für die Fortschrittsbalken
            self.stundenFortschritt?.progress = progressStunden
            self.minutenFortschritt?.progress = progressMinuten
            self.sekundenFortschritt?.progress = progressSekunden
        }
    }

    @objc func timerTick()
    {
        print("Tick")
    }
        
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }


}

